import { useEffect, useState } from 'react';
import { useFramework } from '../useFramework';
export const useAppManifest = (appKey) => {
    const provider = useFramework().modules.app;
    const [value, setValue] = useState(undefined);
    const [error, setError] = useState();
    const [isLoading, setIsLoading] = useState(false);
    useEffect(() => {
        setIsLoading(true);
        const request = provider.getAppManifest(appKey).subscribe({
            next: (value) => setValue(value),
            error: (err) => setError(err),
            complete: () => setIsLoading(false),
        });
        return () => {
            setIsLoading(false);
            request.unsubscribe();
        };
    }, [provider, setValue, setError, setIsLoading, appKey]);
    return { value, error, isLoading };
};
export default useAppManifest;
//# sourceMappingURL=useAppManifest.js.map